const {Client, Intents} = require('discord.js');
const {token, clientId} = require('./config.json');

const CommandParser = require('./commands/CommandParser.js');
const VoteParser = require('./vote/VoteParser');
const BaseInfo = require('./database/BaseInfo.js');


const client = new Client({
  intents: [Intents.FLAGS.GUILDS, Intents.FLAGS.GUILD_MESSAGES, Intents.FLAGS.GUILD_MESSAGE_REACTIONS, Intents.FLAGS.GUILD_MEMBERS],
  partials: ['MESSAGE', 'CHANNEL', 'REACTION']
});

let parser = null;
let voteParser = null;
let baseInfo = null;

client.once('ready', () => {
  baseInfo = new BaseInfo(client);
  voteParser = new VoteParser(client, baseInfo);
  parser = new CommandParser(client, voteParser, baseInfo);
  console.log('Ready!');

});


client.on("messageCreate", (message) => {
  if (!parser) return;
  if (message.author.id !== clientId) {
    parser.parse(message);
  }
});

client.on('messageReactionAdd', async (reaction) => {
  if (reaction.partial) {
    try {
      await reaction.fetch();
    } catch (error) {
      console.error('Something went wrong when fetching the message:', error);
      return;
    }
  }
  voteParser.parse(reaction.message);
});


client.on('guildMemberAdd', member => {
  parser.informeMoi.sayWelcome(member.user.id);
});
client.login(token);
